SharePoint Rest API
===================


Installation
------------

.. code-block:: bash

    pip install sharepoint-rest-api


Setup
-----

Add `sharepoint_rest_api` to ``INSTALLED_APPS`` in settings

.. code-block:: bash

    INSTALLED_APPS = [
        'sharepoint_rest_api',
    ]


Documentation
-------------

Documentation can be found at https://sharepoint-rest-api.readthedocs.io/en/latest/


Links
~~~~~

+--------------------+----------------+--------------+--------------------------+
| Stable             | |master-build| | |master-cov| |                          |
+--------------------+----------------+--------------+--------------------------+
| Development        | |dev-build|    | |dev-cov|    |                          |
+--------------------+----------------+--------------+--------------------------+
| Source Code        |https://github.com/domdinicola/sharepoint-rest-api        |
+--------------------+----------------+-----------------------------------------+
| Issue tracker      |https://github.com/domdinicola/sharepoint-rest-api/issues |
+--------------------+----------------+-----------------------------------------+


.. |master-build| image:: https://secure.travis-ci.org/domdinicola/sharepoint-rest-api.svg?branch=master
                    :target: http://travis-ci.org/domdinicola/sharepoint-rest-api/

.. |master-cov| image:: https://codecov.io/gh/domdinicola/sharepoint-rest-api/branch/master/graph/badge.svg
                    :target: https://codecov.io/gh/domdinicola/sharepoint-rest-api

.. |dev-build| image:: https://secure.travis-ci.org/domdinicola/sharepoint-rest-api.svg?branch=develop
                  :target: http://travis-ci.org/domdinicola/sharepoint-rest-api/

.. |dev-cov| image:: https://codecov.io/gh/domdinicola/sharepoint-rest-api/branch/develop/graph/badge.svg
                    :target: https://codecov.io/gh/domdinicola/sharepoint-rest-api



Compatibility Matrix
--------------------

Stable
~~~~~~
.. image:: https://travis-matrix-badges.herokuapp.com/repos/domdinicola/sharepoint-rest-api/branches/master

Develop
~~~~~~~
.. image:: https://travis-matrix-badges.herokuapp.com/repos/domdinicola/sharepoint-rest-api/branches/develop
